@@ -1,15 +1,19 @@
 package Test::Magpie::ArgumentMatcher;
 {
-  $Test::Magpie::ArgumentMatcher::VERSION = '0.09';
+  $Test::Magpie::ArgumentMatcher::VERSION = '0.10';
 }
 # ABSTRACT: Various templates to catch arguments
 
 use strict;
 use warnings;
 
+use Devel::PartialDump;
 use Exporter qw( import );
+use MooseX::Types::Moose qw( Str CodeRef );
 use Set::Object ();
-use Test::Magpie::Util ();
+use Test::Magpie::Util;
+
+use overload '""' => sub { $_[0]->{name} }, fallback => 1;
 
 our @EXPORT_OK = qw(
     anything
@@ -19,54 +23,79 @@ our @EXPORT_OK = qw(
     type
 );
 
+my $Dumper = Devel::PartialDump->new(pairs => 0);
+
 sub anything {
-    bless sub { return () }, __PACKAGE__;
+    return __PACKAGE__->new(
+        name => 'anything()',
+        matcher => sub { return () },
+    );
 }
 
 sub custom_matcher (&;) {
-    my $test = shift;
-    bless sub {
-        local $_ = $_[0];
-        $test->(@_) ? () : undef
-    }, __PACKAGE__;
+    my ($test) = @_;
+    return __PACKAGE__->new(
+        name => "custom_matcher($test)",
+        matcher => sub {
+            local $_ = $_[0];
+            $test->(@_) ? () : undef
+        },
+    );
 }
 
 sub hash {
     my (%template) = @_;
-    bless sub {
-        my %hash = @_;
-        for (keys %template) {
-            if (my $v = delete $hash{$_}) {
-                return unless Test::Magpie::Util::match($v, $template{$_});
+    return __PACKAGE__->new(
+        name => 'hash(' . $Dumper->dump(%template) . ')',
+        matcher => sub {
+            my %hash = @_;
+            for (keys %template) {
+                if (my $v = delete $hash{$_}) {
+                    return unless Test::Magpie::Util::match($v, $template{$_});
+                }
+                else {
+                    return;
+                }
             }
-            else {
-                return;
-            }
-        }
-        return %hash;
-    }, __PACKAGE__;
+            return %hash;
+        },
+    );
 }
 
 sub set {
     my ($take) = Set::Object->new(@_);
-    bless sub {
-        return Set::Object->new(@_) == $take ? () : undef;
-    }, __PACKAGE__;
+    return __PACKAGE__->new(
+        name => 'set(' . $Dumper->dump(@_) . ')',
+        matcher => sub {
+            return Set::Object->new(@_) == $take ? () : undef;
+        },
+    );
+}
+
+sub type {
+    my ($type) = @_;
+    return __PACKAGE__->new(
+        name => "type($type)",
+        matcher => sub {
+            my ($arg, @in) = @_;
+            $type->check($arg) ? @in : undef
+        },
+    );
+}
+
+
+sub new {
+    my ($class, %args) = @_;
+    ### assert: defined $args{name}
+    ### assert: defined $args{matcher}
+    ### assert: ref( $args{matcher} ) eq 'CODE'
+
+    return bless \%args, $class;
 }
 
 sub match {
     my ($self, @input) = @_;
-    use Carp;
-    confess unless ref $self;
-    return $self->(@input);
-}
-
-sub type {
-    my $type = shift;
-    bless sub {
-        my ($arg, @in) = @_;
-        $type->check($arg) ? @in : undef
-    }, __PACKAGE__;
+    return $self->{matcher}->(@input);
 }
 
 1;
@@ -75,16 +104,18 @@ __END__
 
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Test::Magpie::ArgumentMatcher - Various templates to catch arguments
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
+    use Test::Magpie;
     use Test::Magpie::ArgumentMatcher qw( anything );
-    use Test::Magpie qw( mock verify );
 
     my $mock = mock;
     $mock->push( button => 'red' );
@@ -161,6 +192,8 @@ duplicate arguments B<are ignored>. For example C<1, 1, 2> will match C<1, 2>,
 C<1, 2, 2>. This is probably a bug and I will fix it, but for now I'm mostly
 waiting for a bug report - sorry!
 
+=for Pod::Coverage new match
+
 =head1 AUTHORS
 
 =over 4
